"""Provides link between command and code."""
from .app import main


def start() -> None:
    """Starts actual code."""
    main()
